<?php

class ControllerExtensionPaymentBetatransfer extends Controller
{
    private $error = array();

    public function __construct($registry)
    {
        parent::__construct($registry);
        $this->load->language('extension/payment/betatransfer');
        $this->document->setTitle($this->language->get('heading_title'));
    }

    public function index()
    {
        $data = $this->language->all();

        if (($this->request->server['REQUEST_METHOD'] == 'POST') && !empty($this->validate())) {
            $this->_trimData(array(
                'betatransfer_token',
                'betatransfer_secret',
                'betatransfer_payment_system',
                'betatransfer_total',
            ));

            $this->request->post['betatransfer_total'] = str_replace(',', '.', $this->request->post['betatransfer_total']);

            $this->load->model('setting/setting');
            $this->model_setting_setting->editSetting('betatransfer', $this->request->post);
            $this->session->data['success'] = sprintf($this->language->get('text_success'), $this->language->get('heading_title'));

            $this->response->redirect($this->makeUrl('extension/extension', 'type=payment'));
        }

        $this->load->model('localisation/currency');
        $this->load->model('localisation/geo_zone');
        $this->load->model('localisation/language');
        $this->load->model('localisation/order_status');

        $bt_currencies = array(
            ''    => $this->language->get('text_currency_auto'),
            'RUB' => $this->language->get('text_currency_rub'),
            'UAH' => $this->language->get('text_currency_uah'),
            'USD' => $this->language->get('text_currency_usd'),
            'EUR' => $this->language->get('text_currency_eur')
        );

        $permission = $this->validatePermission();

        if (!$permission) {
            $this->error['warning'] = sprintf($this->language->get('error_permission'), $this->language->get('heading_title'));
        }

        if (!empty($this->session->data['success'])) {
            $data['success'] = $this->session->data['success'];
            unset($this->session->data['success']);
        }

        $data['title_default'] = explode(',', $this->language->get('heading_title'));
        $data['action'] = $this->makeUrl('extension/payment/betatransfer');
        $data['cancel'] = $this->makeUrl('extension/extension', 'type=payment');
        $data['betatransfer_success_url'] = HTTPS_CATALOG . 'index.php?route=extension/payment/betatransfer/success';
        $data['betatransfer_fail_url'] = HTTPS_CATALOG . 'index.php?route=extension/payment/betatransfer/fail';
        $data['betatransfer_pending_url'] = HTTPS_CATALOG . 'index.php?route=extension/payment/betatransfer/success';
        $data['betatransfer_callback_url'] = HTTPS_CATALOG . 'index.php?route=extension/payment/betatransfer/callback';
        $data['permission'] = $permission;
        $data['error_warning'] = isset($this->error['warning']) ? $this->error['warning'] : '';
        $data['error_token'] = isset($this->error['error_token']) ? $this->error['error_token'] : '';
        $data['error_secret'] = isset($this->error['error_secret']) ? $this->error['error_secret'] : '';
        $data['error_payment_system'] = isset($this->error['error_payment_system']) ? $this->error['error_payment_system'] : '';
        $data['currencies'] = array_intersect_key($bt_currencies, $this->model_localisation_currency->getCurrencies());
        $data['oc_languages'] = $this->model_localisation_language->getLanguages();

        $data['breadcrumbs'][] = array(
           'href' => $this->makeUrl('common/dashboard'),
           'text' => $this->language->get('text_home')
        );

        $data['breadcrumbs'][] = array(
            'href' => $this->makeUrl('extension/extension', 'type=payment'),
            'text' => $this->language->get('text_extension')
        );

        $data['breadcrumbs'][] = array(
            'href' => $this->makeUrl('extension/payment/betatransfer'),
            'text' => $this->language->get('heading_title')
        );

        $this->prepareSettings($data);

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('extension/payment/betatransfer', $data));
    }

    public function prepareSettings(&$data)
    {
        $this->load->model('localisation/order_status');
        $data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();

        $this->load->model('localisation/geo_zone');
        $data['geo_zones'] = $this->model_localisation_geo_zone->getGeoZones();

        $list_settings = array(
            'betatransfer_status',
            'betatransfer_sort_order',
            'betatransfer_geo_zone_id',
            'betatransfer_total',
            'betatransfer_order_status_confirm',
            'betatransfer_order_status_success',
            'betatransfer_order_status_fail',
            'betatransfer_langdata',
            'betatransfer_token',
            'betatransfer_secret',
            'betatransfer_payment_system',
            'betatransfer_currency',
        );

        foreach ($list_settings as $setting) {
            if (isset($this->request->post[$setting])) {
                $data[$setting] = $this->request->post[$setting];
            } else {
                $data[$setting] = $this->config->get($setting);
            }
        }

        return $data;
    }

    protected function validate()
    {
        if (!$this->validatePermission()) {
            $this->error['warning'] = sprintf($this->language->get('error_permission'), $this->language->get('heading_title'));
        } else {
            if (!isset($this->request->post['betatransfer_token']) || !trim($this->request->post['betatransfer_token'])) {
                $this->error['warning'][]= $this->error['error_token'] = sprintf($this->language->get('error_form'), $this->language->get('entry_token')) . "<br>";
            }

            if (!isset($this->request->post['betatransfer_secret']) || !trim($this->request->post['betatransfer_secret'])) {
                $this->error['warning'][]= $this->error['error_secret'] = sprintf($this->language->get('error_form'), $this->language->get('entry_secret')) . "<br>";
            }
        }

        return !$this->error;
    }

    protected function validatePermission()
    {
        return $this->user->hasPermission('modify', 'extension/payment/betatransfer');
    }

    protected function _trimData($values)
    {
        foreach ($values as $value) {
            if (isset($this->request->post[$value])) {
                $this->request->post[$value] = trim($this->request->post[$value]);
            }
        }
    }

    protected function makeUrl($route, $url = '')
    {
        return str_replace('&amp;', '&', $this->url->link($route, $url . '&token=' . $this->session->data['token'], 'SSL'));
    }
}
?>
